@@ -1,5 +1,5 @@
-__version__ = "1.4.0.0"
-__author__ = "Jon Kristian Dahl"
+__author__ = "Jon Kristian Dahl, Johannes Heines"
+__version__ = "1.5.1.0"
 __credits__ = "Noritaka Shimizu, Jørgen Eriksson Midtbø"
 
 """
@@ -17,6 +17,9 @@ from .general_utilities import *
 from .kshell_exceptions import *
 from .count_dim import *
 from .parameters import *
+from .compare import Compare
 from .collect_logs import collect_logs, check_multipolarities
 from .script_editing import edit_and_queue_executables
-# from .low_energy_enhancement import * # Not ready for ver. 1.0
+from .partition_editor import partition_editor, test_partition_editor, test_partition_editor_2
+from . import loaders
+from . import data_structures
